@@ -1,9 +1,9 @@
 from django_codemod.constants import DJANGO_3_0, DJANGO_4_0
-from django_codemod.visitors.base import BaseSimpleFuncRenameTransformer
+from django_codemod.visitors.base import BaseFuncRenameTransformer
 
 
-class UGetTextTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils.translation.ugettext``."""
+class UGetTextTransformer(BaseFuncRenameTransformer):
+    """Replace `django.utils.translation.ugettext` by `gettext`."""
 
     deprecated_in = DJANGO_3_0
     removed_in = DJANGO_4_0
@@ -11,8 +11,8 @@ class UGetTextTransformer(BaseSimpleFuncRenameTransformer):
     rename_to = "django.utils.translation.gettext"
 
 
-class UGetTextLazyTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils.translation.ugettext_lazy``."""
+class UGetTextLazyTransformer(BaseFuncRenameTransformer):
+    """Replace `django.utils.translation.ugettext_lazy` by `gettext_lazy`."""
 
     deprecated_in = DJANGO_3_0
     removed_in = DJANGO_4_0
@@ -20,8 +20,8 @@ class UGetTextLazyTransformer(BaseSimpleFuncRenameTransformer):
     rename_to = "django.utils.translation.gettext_lazy"
 
 
-class UGetTextNoopTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils.translation.ugettext_noop``."""
+class UGetTextNoopTransformer(BaseFuncRenameTransformer):
+    """Replace `django.utils.translation.ugettext_noop` by `gettext_noop`."""
 
     deprecated_in = DJANGO_3_0
     removed_in = DJANGO_4_0
@@ -29,8 +29,8 @@ class UGetTextNoopTransformer(BaseSimpleFuncRenameTransformer):
     rename_to = "django.utils.translation.gettext_noop"
 
 
-class UNGetTextTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils.translation.ungettext``."""
+class UNGetTextTransformer(BaseFuncRenameTransformer):
+    """Replace `django.utils.translation.ungettext` by `ngettext`."""
 
     deprecated_in = DJANGO_3_0
     removed_in = DJANGO_4_0
@@ -38,8 +38,8 @@ class UNGetTextTransformer(BaseSimpleFuncRenameTransformer):
     rename_to = "django.utils.translation.ngettext"
 
 
-class UNGetTextLazyTransformer(BaseSimpleFuncRenameTransformer):
-    """Resolve deprecation of ``django.utils.translation.ungettext_lazy``."""
+class UNGetTextLazyTransformer(BaseFuncRenameTransformer):
+    """Replace `django.utils.translation.ungettext_lazy` by `ngettext_lazy`."""
 
     deprecated_in = DJANGO_3_0
     removed_in = DJANGO_4_0
